@@ -1,8 +1,9 @@
 class Admin::CategoriesController < Admin::BaseController
   resource_controller
+  before_filter :master_shop_check
 
   index.before do
-    @category = Category.find_by_id(params[:id])
+    @category = Category.find_by_id(params[:id].to_i)
     if @category
       params[:category_id] ||= @category.parent_id 
     end
@@ -11,18 +12,6 @@ class Admin::CategoriesController < Admin::BaseController
     @category ||= Category.new
   end
 
-  create.before do
-    @category.position_up
-  end
-
-  create.after do
-    Category.update_all("children_ids = null")
-  end
-
-  update.after do
-    Category.update_all("children_ids = null")
-  end
-
   [create, update, destroy].each do |action|
     action.wants.html do
       redirect_to :action => "index", :category_id => @category.parent_id
@@ -38,13 +27,4 @@ class Admin::CategoriesController < Admin::BaseController
     super
     redirect_to :action => "index", :category_id => @record.parent_id
   end
-
-  destroy.before do
-    @parent_id = @category.parent_id
-  end
-
-  destroy.after do
-    Category.re_position(@parent_id)
-    Category.update_all("children_ids = null")
-  end
 end
